/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

gTestfile = 'instanceof-001.js';

/**
 *  Verify that we can use the instanceof operator on java objects.
 *
 *
 */
var SECTION = "instanceof";
var VERSION = "1_4";
var TITLE   = "LiveConnect 3.0 JavaScript to Java Data Type Conversion " +
  SECTION;
startTest();


new TestCase(
  "\"hi\" instance of java.lang.String",
  false,
  "hi" instanceof java.lang.String );

new TestCase(
  "new java.lang.String(\"hi\") instanceof java.lang.String",
  true,
  new java.lang.String("hi") instanceof java.lang.String );

new TestCase(
  "new java.lang.String(\"hi\") instanceof java.lang.Object",
  true,
  new java.lang.String("hi") instanceof java.lang.Object );

new TestCase(
  "java.lang.String instanceof java.lang.Class",
  false,
  java.lang.String instanceof java.lang.Class );

new TestCase(
  "java.lang.Class.forName(\"java.lang.String\") instanceof java.lang.Class",
  true,
  java.lang.Class.forName("java.lang.String") instanceof java.lang.Class );

new TestCase(
  "new java.lang.Double(5.0) instanceof java.lang.Double",
  true,
  new java.lang.Double(5.0) instanceof java.lang.Double );

new TestCase(
  "new java.lang.Double(5.0) instanceof java.lang.Number",
  true,
  new java.lang.Double(5.0) instanceof java.lang.Number );

new TestCase(
  "new java.lang.String(\"hi\").getBytes() instanceof java.lang.Double",
  true,
  new java.lang.Double(5.0) instanceof java.lang.Double );

test();
